@@ -6,7 +6,7 @@ import transaction
 from zope.interface import implements
 
 from Products.CMFCore.utils import getToolByName
-from Products.Archetypes.atapi import *
+from Products.Archetypes import atapi
 from Products.Archetypes.interfaces import IBaseContent
 from Products.plonehrm.interfaces import IEmployeeModule
 from plonehrm.jobperformance import config
@@ -14,58 +14,59 @@ from plonehrm.jobperformance.interfaces import IJobPerformanceInterview
 
 from plonehrm.jobperformance import JobMessageFactory as _
 
-schema = Schema((
-    StringField(
+schema = atapi.Schema((
+    atapi.StringField(
         name='template',
-        widget=SelectionWidget(
+        widget=atapi.SelectionWidget(
             format='select',
             condition='not:object/template_chosen',
             label=_(u'template', default=u'Template'),
-        ),
+            ),
         required=1,
         vocabulary='_templates'
-    ),
-    DateTimeField(
+        ),
+    atapi.DateTimeField(
         name='date',
         default_method=DateTime,
-        widget=CalendarWidget(
+        widget=atapi.CalendarWidget(
             label=_(u'label_date', default=u'Date'),
-        )
-    ),
-    TextField('text',
-              required=False,
-              seachable=False,
-              primary=True,
-              default_output_type = 'text/x-html-safe',
-              widget = RichWidget(
-                        description = '',
-                        label = _(u'label_body_text', default=u'Body Text'),
-                        rows = 25,
-                        condition='object/template_chosen'),
-    ),
-    LinesField(
+            )
+        ),
+    atapi.TextField(
+        'text',
+        required=False,
+        seachable=False,
+        primary=True,
+        default_output_type = 'text/x-html-safe',
+        widget = atapi.RichWidget(
+            description = '',
+            label = _(u'label_body_text', default=u'Body Text'),
+            rows = 25,
+            condition='object/template_chosen'
+            ),
+        ),
+    atapi.LinesField(
         name='improvementAreas',
-        widget=LinesWidget(
+        widget=atapi.LinesWidget(
             condition='object/template_chosen',
             label=_(u'label_improvementAreas', default=u'Improvement areas'),
-        )
-    ),
-),
-)
+            )
+        ),
+    ))
 
-Interview_schema = BaseSchema.copy() + schema.copy()
+Interview_schema = atapi.BaseSchema.copy() + schema.copy()
 
 
-class JobPerformanceInterview(BaseContent):
+class JobPerformanceInterview(atapi.BaseContent):
     """
     """
-    __implements__ = (BaseContent.__implements__, )
+    __implements__ = (atapi.BaseContent.__implements__, )
     implements(IEmployeeModule, IBaseContent, IJobPerformanceInterview)
     _at_rename_after_creation = True
     schema = Interview_schema
 
     # plonehrm.absence wants to know what the main date is:
-    main_date = ATDateTimeFieldProperty('date')
+    main_date = atapi.ATDateTimeFieldProperty('date')
 
     def _templates(self):
         """
@@ -75,8 +76,8 @@ class JobPerformanceInterview(BaseContent):
             return []
         else:
             items = [(item.id, item.Title())
-                     for item in jobtool.contentValues()]
-            return DisplayList(items)
+                     for item in jobtool.listTemplates()]
+            return atapi.DisplayList(items)
 
     def initializeArchetype(self, **kwargs):
         """Pre-populate the jobperformance interview.
@@ -84,7 +85,7 @@ class JobPerformanceInterview(BaseContent):
         Frankly, we would want a separate add form here, instead of an
         edit form that is also used for adding.
         """
-        BaseContent.initializeArchetype(self, **kwargs)
+        atapi.BaseContent.initializeArchetype(self, **kwargs)
         # Do not make the text required.
         self.schema['text'].required = False
         transaction.savepoint(optimistic=True)
@@ -112,4 +113,4 @@ class JobPerformanceInterview(BaseContent):
         return len(self.template) > 0
 
 
-registerType(JobPerformanceInterview, config.PROJECTNAME)
+atapi.registerType(JobPerformanceInterview, config.PROJECTNAME)
